@@ -351,9 +351,7 @@ update(module_ty *mp, server_ty *sp, string_ty *client_side_0,
 	path = change_file_version_path(mcp->cp, src, &need_to_unlink);
 	is_local = !!change_file_find(mcp->cp, src->file_name, view_path_first);
 	os_become_orig();
-	ip = input_file_open(path);
-	if (need_to_unlink)
-	    input_file_unlink_on_close(ip);
+	ip = input_file_open(path, need_to_unlink);
 	if (is_local && os_executable(path))
 	    src->executable = true;
 	if (is_local)
