@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999, 2002 Peter Miller;
+ *	Copyright (C) 1999, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,8 +23,9 @@
 #ifndef AEDIST_SEND_H
 #define AEDIST_SEND_H
 
-#include <main.h>
-
-void send_main(void(*)(void));
+/**
+  * The send_main function implements the aedist -send option.
+  */
+void send_main(void);
 
 #endif /* AEDIST_SEND_H */
