@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993 Peter Miller.
+ *	Copyright (C) 1991-1993, 2002 Peter Miller.
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 #include <main.h>
 
-void new_release _((void));
+void new_release(void);
 
 #endif /* AEGIS_AENRLS_H */
-
