@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1998, 2000, 2002 Peter Miller;
+ *	Copyright (C) 1998, 2000, 2002, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void rect(char *, int, int, char *);
+void rect(const char *, int, int, const char *);
 void rect_color(int, int, int);
 void rect_bevel(int);
 void rect_mime(int);
