@@ -25,10 +25,6 @@
 
 #include <main.h>
 
-extern int cxx_warning;
-extern int warning;
-extern int limit;
-
 void check(const char *filename);
 
 #endif /* CKLINLEN_CHECK_H */
