@@ -1,6 +1,6 @@
 /*
  *	aegis - a project change supervisor
- *	Copyright (C) 1994, 1996, 1997, 2002 Peter Miller;
+ *	Copyright (C) 1994, 1996, 1997, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,16 +25,22 @@
 
 #include <config.h>
 
-#if !defined(HAVE_STRCASECMP)
+#if !HAVE_STRCASECMP
 int strcasecmp(const char *, const char *);
 #endif
 
-#if !defined(HAVE_STRNCASECMP)
+#if !HAVE_STRNCASECMP
 int strncasecmp(const char *, const char *, size_t);
 #endif
 
-#if !defined(HAVE_STRSIGNAL)
-char *strsignal(int);
+#if !HAVE_DECL_STRSIGNAL
+extern "C" {
+const char *strsignal(int);
+}
+#endif
+
+#if !HAVE_STRVERSCMP
+int strverscmp(const char *, const char *);
 #endif
 
 #if STDC_HEADERS || HAVE_STRING_H
@@ -48,4 +54,16 @@ char *strsignal(int);
 #  include <strings.h>
 #endif
 
+#if !HAVE_STRLCPY
+size_t strlcpy(char *dst, const char *src, size_t size);
+#endif
+#if !HAVE_STRLCAT
+size_t strlcat(char *dst, const char *src, size_t size);
+#endif
+
+#undef strcat
+#define strcat strcat_is_unsafe__use_strlcat_instead@
+#undef strcpy
+#define strcpy strcpy_is_unsafe__use_strlcpy_instead@
+
 #endif /* COMMON_AC_STRING_H */
