@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1998, 1999, 2001, 2002 Peter Miller;
+ *	Copyright (C) 1998, 1999, 2001-2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -40,6 +40,16 @@
 #endif
 #endif
 
+/*
+ * For libcurl to work, it must be able to run in the top process,
+ * not forked off in a setuid worker process.  (This isn't a problem
+ * for most modern systems.)
+ */
+#ifdef CONF_NO_seteuid
+#undef HAVE_CURL_CURL_H
+#undef HAVE_LIBCURL
+#endif
+
 /*
  * Make sure Solaris includes POSIX extensions.
  */
@@ -105,4 +115,22 @@
 #define SINGLE_USER
 #endif
 
+/*
+ * Cope with parts of libmagic being missing
+ * (or being something else, e.g. on HP/UX)
+ */
+#if !HAVE_MAGIC_H || !HAVE_LIBMAGIC || !HAVE_MAGIC_FILE
+# ifdef HAVE_MAGIC_H
+#  undef HAVE_MAGIC_H
+# endif
+# ifdef HAVE_LIBMAGIC
+#  undef HAVE_LIBMAGIC
+# endif
+# ifdef HAVE_MAGIC_FILE
+#  undef HAVE_MAGIC_FILE
+# endif
+#endif
+
+#define NDEBUG 1
+
 #endif /* COMMON_CONFIG_MESSY_H */
