@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1993, 1995, 1999, 2002 Peter Miller;
+ *	Copyright (C) 1991-1993, 1995, 1999, 2002, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,26 +25,21 @@
 
 #include <main.h>
 
-#define error /!/!/
+/** \addtogroup Error
+  * \brief Error functions
+  * \ingroup Common
+  * @{
+  */
 void error_raw(const char *, ...);
-#define fatal /!/!/
 void fatal_raw(const char *, ...) NORETURN;
 
 void nerror(const char *, ...);
 void nfatal(const char *, ...) NORETURN;
 
-typedef void (*quit_ty)(int);
-void quit_register(quit_ty);
-void quit(int) NORETURN;
-
-int assert_failed(const char *condition, const char *file, int line)
+void assert_failed(const char *condition, const char *file, int line)
     NORETURN;
 #ifdef DEBUG
-# if defined(__STDC__) || defined(__stdc__)
-#  define assert(c) ((void)((c) != 0 || assert_failed(#c, __FILE__, __LINE__)))
-# else
-#  define assert(c) ((void)((c) != 0 || assert_failed("c", __FILE__, __LINE__)))
-# endif
+# define assert(c) ((c) ? (void)0 : assert_failed(#c, __FILE__, __LINE__))
 #else
 # define assert(c)
 #endif
@@ -57,4 +52,5 @@ int assert_failed(const char *condition, const char *file, int line)
 		__LINE__						\
 	)
 
+/** @} */
 #endif /* ERROR_H */
