@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1998, 1999, 2001, 2002 Peter Miller;
+#	Copyright (C) 1998, 1999, 2001-2003 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -61,7 +61,7 @@ fubar
 # The book says that the icon files need to be in the SOURCES directory.
 # Actually, they need to be in the same directory as the tarball.
 #
-rpm -ta --rcfile /usr/lib/rpm/rpmrc:${tmp}/rpmrc --verbose --verbose $2
+rpmbuild -ta --rcfile /usr/lib/rpm/rpmrc:${tmp}/rpmrc --verbose --verbose $2
 test $? -eq 0 || exit 1
 
 exit 0
