@@ -1,8 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1992, 1993, 1995, 1999-2002 Peter Miller;
-#	All rights reserved.
+#	Copyright (C) 1992, 1993, 1995, 1999-2004 Peter Miller
 #
 #	This program is free software; you can redistribute it and/or modify
 #	it under the terms of the GNU General Public License as published by
@@ -46,12 +45,24 @@ quit()
 	exit 1
 }
 
+#
+# Get any aliases for the project
+#
+aliases=`aegis -list Project_Aliases -unf -p $project | awk '{ print $1 }'`
+if [ "$aliases" ]
+then
+    # format as comma separated list in brackets
+   aliases=" ["`echo $aliases | tr ' ' ','`"]"
+fi
+
+to=`aesub "\${email_address -comma $developer $reviewer}"`
+
 #
 # build the notice to be mailed
 #
 cat > $tmp << TheEnd
-Subject: Project $project: Change $change: failed review
-To: $developer, $reviewer
+Subject: Project ${project}$aliases: Change $change: failed review
+To: $to
 
 The change described below has failed review.
 It has been returned to the developer for further work.
