@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <main.h>
 
-void list_project_inappropriate _((void));
+void list_project_inappropriate(void);
 
 #endif /* LIBAEGIS_AEL_PROJECT_INAPPROPRIAT_H */
