@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1994 Peter Miller.
+ *	Copyright (C) 1994, 2002 Peter Miller.
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <aer/expr.h>
 
-rpt_expr_ty *rpt_expr_list _((void));
-rpt_expr_ty *rpt_expr_comma _((rpt_expr_ty *, rpt_expr_ty *));
+rpt_expr_ty *rpt_expr_list(void);
+rpt_expr_ty *rpt_expr_comma(rpt_expr_ty *, rpt_expr_ty *);
 
 #endif /* AEGIS_AER_EXPR_LIST_H */
