@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 2001 Peter Miller;
+ *	Copyright (C) 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,6 @@
 
 struct change_ty; /* forward */
 
-rpt_value_ty *rpt_value_pconf _((struct change_ty *));
+rpt_value_ty *rpt_value_pconf(struct change_ty *);
 
 #endif /* LIBAEGIS_AER_VALUE_PCONF_H */
