@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 2000, 2002 Peter Miller;
+ *	Copyright (C) 2000, 2002, 2005 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,29 @@ struct change_ty;
 struct string_list_ty;
 struct user_ty;
 
-batch_result_list_ty *change_test_batch_fake(struct change_ty *,
-	struct string_list_ty *, struct user_ty *, int, int, int);
+/**
+  * The change_test_batch_fake function is used to run a batch of tests
+  * using the test_command field of the project configuration file.  This
+  * is because no batch_test_command field has been specified.
+  *
+  * \param cp
+  *     The change being tested.
+  * \param wlp
+  *     The list of test files names to be run.
+  * \param up
+  *     The user to run the tests as.
+  * \param baseline
+  *     true if this is a baseline (negative) test, or
+  *     false if this is a regular (positive) test.
+  * \param current
+  *     The number of tests completed so far.
+  * \param total
+  *     The total number opf tests to be run.
+  * \param time_limit
+  *     zero if there is no time limit, or non-zero if testing should
+  *     cease at this time.
+  */
+batch_result_list_ty *change_test_batch_fake(change_ty *cp, string_list_ty *wlp,
+    user_ty *up, bool baseline, int current, int total, time_t time_limit);
 
 #endif /* LIBAEGIS_CHANGE_TEST_BATCH_FAKE_H */
