@@ -1,24 +1,24 @@
-/*
- *	aegis - project change supervisor
- *	Copyright (C) 2002 Peter Miller;
- *	All rights reserved.
- *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
- *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
- *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for libaegis/dir_stack.c
- */
+//
+//	aegis - project change supervisor
+//	Copyright (C) 2002, 2004 Peter Miller;
+//	All rights reserved.
+//
+//	This program is free software; you can redistribute it and/or modify
+//	it under the terms of the GNU General Public License as published by
+//	the Free Software Foundation; either version 2 of the License, or
+//	(at your option) any later version.
+//
+//	This program is distributed in the hope that it will be useful,
+//	but WITHOUT ANY WARRANTY; without even the implied warranty of
+//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//	GNU General Public License for more details.
+//
+//	You should have received a copy of the GNU General Public License
+//	along with this program; if not, write to the Free Software
+//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+//
+// MANIFEST: interface definition for libaegis/dir_stack.c
+//
 
 #ifndef LIBAEGIS_DIR_STACK_H
 #define LIBAEGIS_DIR_STACK_H
@@ -34,9 +34,8 @@ enum dir_stack_walk_message_t
 	dir_stack_walk_special,
 	dir_stack_walk_symlink
 };
-typedef enum dir_stack_walk_message_t dir_stack_walk_message_t;
 
-struct stat; /* forward */
+struct stat; // forward
 
 /**
   * The TOP_LEVEL_SYMLINK flags is returned in the depth_p field to
@@ -186,4 +185,4 @@ void dir_stack_stat(string_list_ty *viewpath, string_ty *filename,
   */
 string_ty *dir_stack_relative(string_list_ty *viewpath, string_ty *abspath);
 
-#endif /* LIBAEGIS_DIR_STACK_H */
+#endif // LIBAEGIS_DIR_STACK_H
