@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 1999, 2001, 2003, 2004 Peter Miller;
+//	Copyright (C) 1999, 2001, 2003-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -23,18 +23,19 @@
 #include <input/crlf.h>
 #include <input/file.h>
 #include <input/file_text.h>
-#include <str.h>
 
 
 input_ty *
 input_file_text_open(string_ty *fn)
 {
-    return input_crlf(input_file_open(fn), 1);
+    return new input_crlf(input_file_open(fn), 1);
 }
 
 
 void
 input_file_text_escaped_newline(input_ty *ip)
 {
-    input_crlf_escaped_newline(ip);
+    input_crlf *icp = dynamic_cast<input_crlf *>(ip);
+    if (icp)
+	icp->escaped_newline();
 }
