@@ -1,6 +1,6 @@
 //
 //	aegis - project change supervisor
-//	Copyright (C) 2002-2004 Peter Miller;
+//	Copyright (C) 2002-2005 Peter Miller;
 //	All rights reserved.
 //
 //	This program is free software; you can redistribute it and/or modify
@@ -24,31 +24,25 @@
 #include <str.h>
 
 
-int
-input_read_strict(input_ty *ip, void *buf, size_t len)
+bool
+input_ty::read_strict(void *buf, size_t len)
 {
-    long	    asked;
-    long	    got;
-
-    asked = len;
-    got = 0;
+    long asked = len;
+    long got = 0;
     while (len > 0)
     {
-	long            result;
-
-	result = input_read(ip, buf, len);
+	long result = read(buf, len);
 	if (result <= 0)
 	{
-	    string_ty       *s;
-
 	    if (got == 0)
-		return 0;
-	    s = str_format("short read (asked %ld, got %ld)", asked, got);
-	    input_fatal_error(ip, s->str_text);
+		return false;
+	    nstring s =
+		nstring::format("short read (asked %ld, got %ld)", asked, got);
+	    fatal_error(s.c_str());
 	}
 	len -= result;
 	got += result;
 	buf = (char *)buf + result;
     }
-    return 1;
+    return true;
 }
