@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1993, 1995, 1997, 1999, 2002 Peter Miller;
+ *	Copyright (C) 1991-1993, 1995, 1997, 1999, 2002-2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,11 +25,6 @@
 
 #include <main.h>
 
-#define DEFAULT_PRINTER_WIDTH 132
-#define DEFAULT_PRINTER_LENGTH 66
-
-#define MAX_PAGE_WIDTH 5000
-
 void option_progname_set(char *);
 char *option_progname_get(void);
 
@@ -41,9 +36,7 @@ void option_terse_set(void(*)(void));
 int option_terse_get(void);
 
 void option_page_width_set(int columns, void (*usage)(void));
-int option_page_width_get(int);
 void option_page_length_set(int rows, void (*usage)(void));
-int option_page_length_get(int);
 
 void option_tab_width_set(int, void(*)(void));
 int option_tab_width_get(void);
@@ -51,4 +44,7 @@ int option_tab_width_get(void);
 void option_page_headers_set(int, void(*)(void));
 int option_page_headers_get(void);
 
+void option_signed_off_by_argument(void(*)(void));
+bool option_signed_off_by_get(bool dflt);
+
 #endif /* OPTION_H */
