@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
 struct sub_context_ty; /* existence */
 struct wstring_list_ty; /* existence */
 
-struct wstring_ty *sub_library_directory _((struct sub_context_ty *,
-	struct wstring_list_ty *));
+struct wstring_ty *sub_library_directory(struct sub_context_ty *,
+	struct wstring_list_ty *);
 
 #endif /* LIBAEGIS_SUB_LIBRAR_DIREC_H */
