@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1997, 1998, 1999 Peter Miller;
+#	Copyright (C) 1997-1999, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,14 @@ export LINES
 COLS=80
 export COLS
 
+#
+# The working days calculations depend on the results of the localtime()
+# function, so the timezone will affect the results.  By setting TZ we
+# get consistent behaviour.
+#
+TZ=GMT0
+export TZ
+
 USER=${USER:-${LOGNAME:-`whoami`}}
 
 work=${AEGIS_TMP:-/tmp}/$$
@@ -96,25 +104,6 @@ export AEGIS_MESSAGE_LIBRARY
 unset LANG
 unset LANGUAGE
 
-#
-# If the C compiler is called something other than ``cc'', as discovered
-# by the configure script, create a shell script called ``cc'' which
-# invokes the correct C compiler.  Make sure the current directory is in
-# the path, so that it will be invoked.
-#
-if test "$CC" != "" -a "$CC" != "cc"
-then
-	cat >> $work/cc << fubar
-#!/bin/sh
-exec $CC \$*
-fubar
-	if test $? -ne 0 ; then no_result; fi
-	chmod a+rx $work/cc
-	if test $? -ne 0 ; then no_result; fi
-	PATH=${work}:${PATH}
-	export PATH
-fi
-
 #
 # test the working_days functionality
 #
