@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1999, 2000 Peter Miller;
+#	Copyright (C) 1999, 2000, 2005 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -108,7 +108,7 @@ AEGIS_PROJECT=foo ; export AEGIS_PROJECT
 #
 # make the directories
 #
-activity="working directory 81"
+activity="working directory 111"
 mkdir $work $work/lib
 if test $? -ne 0 ; then no_result; fi
 chmod 777 $work/lib
@@ -127,14 +127,14 @@ unset LANGUAGE
 #
 # make a new project
 #
-activity="new project 161"
+activity="new project 130"
 $bin/aegis -npr foo -vers "" -dir $workproj > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # change project attributes
 #
-activity="project attributes 168"
+activity="project attributes 137"
 cat > $tmp << 'end'
 description = "A bogus project created to test the aedist functionality.";
 developer_may_review = true;
@@ -149,7 +149,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # add the staff
 #
-activity="staff 207"
+activity="staff 152"
 $bin/aegis -nd $USER > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 $bin/aegis -nrv $USER > log 2>&1
@@ -168,7 +168,7 @@ AEGIS_PROJECT=foo.4.2 ; export AEGIS_PROJECT
 #
 # create a new change
 #
-activity="new change 183"
+activity="new change 171"
 cat > $tmp << 'end'
 brief_description = "The first change";
 cause = internal_bug;
@@ -186,8 +186,8 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # add a new files to the change
 #
-activity="new file 224"
-$bin/aegis -nf $workchan/main.c $workchan/config -nl > log 2>&1
+activity="new file 189"
+$bin/aegis -nf $workchan/main.c $workchan/aegis.conf -nl > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 cat > $workchan/main.c << 'end'
 /* $Id$ */
@@ -195,7 +195,7 @@ int main() { test(); exit(0); return 0; }
 end
 if test $? -ne 0 ; then no_result; fi
 
-cat > $workchan/config << 'end'
+cat > $workchan/aegis.conf << 'end'
 build_command = "exit 0";
 link_integration_directory = true;
 create_symlinks_before_build = true;
@@ -217,21 +217,21 @@ if test $? -ne 0 ; then no_result; fi
 #
 # build the change
 #
-activity="build 295"
+activity="build 220"
 $bin/aegis -build -nl -v > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # difference the change
 #
-activity="diff 302"
+activity="diff 227"
 $bin/aegis -diff > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # now make a distribution set
 #
-activity="aedist -send 316"
+activity="aedist -send 234"
 $bin/aedist -send -o test.out -ndh > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
@@ -245,7 +245,7 @@ export PATH
 #
 # now receive it
 #
-activity="aedist -receive 241"
+activity="aedist -receive 248"
 $bin/aedist -receive -f test.out -dir $workchan.2 > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
