@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 2002, 2004 Peter Miller;
+#	Copyright (C) 2002, 2004, 2005 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -118,11 +118,11 @@ export AEGIS_PATH
 #
 # test for the symlink bug
 #
-activity="new project 122"
+activity="new project 121"
 $bin/aegis -npr test -version '' -v -dir $work/proj.dir > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="project attributes 126"
+activity="project attributes 125"
 cat > paf << 'fubar'
 developer_may_review = true;
 developer_may_integrate = true;
@@ -133,7 +133,7 @@ if test $? -ne 0 ; then no_result; fi
 $bin/aegis -pa -f paf -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="staff 137"
+activity="staff 136"
 $bin/aegis -nd $USER -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 $bin/aegis -nrv $USER -v > log 2>&1
@@ -141,7 +141,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 $bin/aegis -ni $USER -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="new change 145"
+activity="new change 144"
 cat > caf << 'fubar'
 brief_description = "one";
 cause = internal_enhancement;
@@ -151,15 +151,15 @@ if test $? -ne 0 ; then no_result; fi
 $bin/aegis -nc -f caf -v -p test > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="develop begin 155"
+activity="develop begin 154"
 $bin/aegis -db 10 -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="new file 159"
-$bin/aegis -nf $work/test.C010/config $work/test.C010/fred \
+activity="new file 158"
+$bin/aegis -nf $work/test.C010/aegis.conf $work/test.C010/fred \
 	$work/test.C010/barney -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
-cat > $work/test.C010/config << 'fubar'
+cat > $work/test.C010/aegis.conf << 'fubar'
 build_command = "exit 0";
 history_get_command =
 	"co -u'$e' -p $h,v > $o";
@@ -184,42 +184,42 @@ if test $? -ne 0 ; then no_result; fi
 echo one > $work/test.C010/barney
 if test $? -ne 0 ; then no_result; fi
 
-activity="build 188"
+activity="build 187"
 $bin/aegis -b -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="diff 192"
+activity="diff 191"
 $bin/aegis -diff -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="develop end 196"
+activity="develop end 195"
 $bin/aegis -de -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="review pass 200"
+activity="review pass 199"
 $bin/aegis -rpass 10 -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate begin 204"
+activity="integrate begin 203"
 $bin/aegis -ib 10 -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate build 208"
+activity="integrate build 207"
 $bin/aegis -b -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate diff 212"
+activity="integrate diff 211"
 $bin/aegis -diff -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate pass 216"
+activity="integrate pass 215"
 $bin/aegis -ipass -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # now create a branch
 #
-activity="new branch 223"
+activity="new branch 222"
 $bin/aegis -nbr -p test 1 -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
@@ -230,7 +230,7 @@ export AEGIS_PROJECT
 # The first change on the branch edits barney,
 # and leaves fred alone.
 #
-activity="new change 234"
+activity="new change 233"
 cat > caf << 'fubar'
 brief_description = "the second change";
 cause = internal_enhancement;
@@ -239,50 +239,50 @@ if test $? -ne 0 ; then no_result; fi
 $bin/aegis -nc -f caf -v -p test.1 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="develop begin 243"
+activity="develop begin 242"
 $bin/aegis -db 10 -v > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="copy file 247"
+activity="copy file 246"
 $bin/aegis -cp $work/test.1.C010/barney -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 echo two > $work/test.1.C010/barney
 if test $? -ne 0 ; then no_result; fi
 
-activity="build 254"
+activity="build 253"
 $bin/aegis -b -v > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="diff 258"
+activity="diff 257"
 $bin/aegis -diff -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="develop end 262"
+activity="develop end 261"
 $bin/aegis -de -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="review pass 266"
+activity="review pass 265"
 $bin/aegis -rpass 10 -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate begin 270"
+activity="integrate begin 269"
 $bin/aegis -ib 10 -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate build 274"
+activity="integrate build 273"
 $bin/aegis -b -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate diff 278"
+activity="integrate diff 277"
 $bin/aegis -diff -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="integrate pass 282"
+activity="integrate pass 281"
 $bin/aegis -ipass -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="new change 289"
+activity="new change 285"
 cat > caf << 'fubar'
 brief_description = "the third change";
 cause = internal_enhancement;
@@ -291,19 +291,19 @@ if test $? -ne 0 ; then no_result; fi
 $bin/aegis -nc -f caf -v -p test.1 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="develop begin 298"
+activity="develop begin 294"
 $bin/aegis -db 11 -v > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="check link 305"
+activity="check link 298"
 test -h $work/test.1.C011/barney
 if test $? -ne 0 ; then fail; fi
 
-activity="check link 309"
-test -h $work/test.1.C011/config
+activity="check link 302"
+test -h $work/test.1.C011/aegis.conf
 if test $? -ne 0 ; then fail; fi
 
-activity="check link 313"
+activity="check link 306"
 test -h $work/test.1.C011/fred
 if test $? -ne 0 ; then fail; fi
 
