@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 2003, 2004 Peter Miller;
+#	Copyright (C) 2003-2005 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -116,7 +116,7 @@ AEGIS_PROJECT=foo ; export AEGIS_PROJECT
 #
 # make the directories
 #
-activity="working directory 118"
+activity="working directory 119"
 mkdir $work $work/lib
 if test $? -ne 0 ; then no_result; fi
 chmod 777 $work/lib
@@ -135,14 +135,14 @@ unset LANGUAGE
 #
 # make a new project
 #
-activity="new project 137"
+activity="new project 138"
 $bin/aegis -npr foo -vers "" -dir $workproj > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # change project attributes
 #
-activity="project attributes 144"
+activity="project attributes 145"
 cat > $tmp << 'end'
 description = "A bogus project created to test the aemt functionality.";
 developer_may_review = true;
@@ -157,7 +157,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # add the staff
 #
-activity="staff 159"
+activity="staff 160"
 $bin/aegis -nd $USER > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 $bin/aegis -nrv $USER > log 2>&1
@@ -170,7 +170,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # create a new change
 #
-activity="new change 172"
+activity="new change 173"
 cat > $tmp << 'end'
 brief_description = "The first change";
 cause = internal_bug;
@@ -188,8 +188,8 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # add a new files to the change
 #
-activity="new file 190"
-$bin/aegis -nf  $workchan/config $workchan/bogus -nl > log 2>&1
+activity="new file 191"
+$bin/aegis -nf  $workchan/aegis.conf $workchan/bogus -nl > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 cat > $workchan/bogus << 'end'
@@ -197,7 +197,7 @@ the trunk version
 end
 if test $? -ne 0 ; then no_result; fi
 
-cat > $workchan/config << 'end'
+cat > $workchan/aegis.conf << 'end'
 build_command = "exit 0";
 create_symlinks_before_build = true;
 remove_symlinks_after_build = false;
@@ -221,49 +221,49 @@ if test $? -ne 0 ; then no_result; fi
 #
 # build the change
 #
-activity="build 221"
+activity="build 224"
 $bin/aegis -build -nl -v > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # difference the change
 #
-activity="diff 228"
+activity="diff 231"
 $bin/aegis -diff > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # finish development of the change
 #
-activity="develop end 235"
+activity="develop end 238"
 $bin/aegis -de > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # pass the review
 #
-activity="review pass 242"
+activity="review pass 245"
 $bin/aegis -rpass -c 1 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # start integrating
 #
-activity="integrate begin 249"
+activity="integrate begin 252"
 $bin/aegis -ib 1 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # integrate build
 #
-activity="build 256"
+activity="build 259"
 $bin/aegis -b -nl -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # pass the integration
 #
-activity="integrate pass 263"
+activity="integrate pass 266"
 $bin/aegis -intpass -nl > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
@@ -272,7 +272,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # create a branch
 #
-activity="new branch 272"
+activity="new branch 275"
 $bin/aegis -nbr -p foo 2 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
@@ -284,7 +284,7 @@ export AEGIS_PROJECT
 #
 # create a new change
 #
-activity="new change 284"
+activity="new change 287"
 cat > $tmp << 'end'
 brief_description = "The second change";
 cause = internal_bug;
@@ -302,7 +302,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # add files to the change
 #
-activity="copy file 302"
+activity="copy file 305"
 $bin/aegis -cp  $workchan/bogus -nl > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
@@ -314,56 +314,56 @@ if test $? -ne 0 ; then no_result; fi
 #
 # build the change
 #
-activity="build 314"
+activity="build 317"
 $bin/aegis -build -nl -v > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # difference the change
 #
-activity="diff 321"
+activity="diff 324"
 $bin/aegis -diff > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # finish development of the change
 #
-activity="develop end 328"
+activity="develop end 331"
 $bin/aegis -de > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # pass the review
 #
-activity="review pass 335"
+activity="review pass 338"
 $bin/aegis -rpass -c 3 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # start integrating
 #
-activity="integrate begin 342"
+activity="integrate begin 345"
 $bin/aegis -ib 3 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # integrate build
 #
-activity="build 349"
+activity="build 352"
 $bin/aegis -b -nl -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # integrate diff
 #
-activity="diff 356"
+activity="diff 359"
 $bin/aegis -diff -nl -v > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 #
 # pass the integration
 #
-activity="integrate pass 363"
+activity="integrate pass 366"
 $bin/aegis -intpass -nl > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
@@ -372,7 +372,7 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # create a new change
 #
-activity="new change 372"
+activity="new change 375"
 cat > $tmp << 'end'
 brief_description = "The third change";
 cause = internal_bug;
@@ -390,11 +390,11 @@ if test $? -ne 0 ; then cat log; no_result; fi
 #
 # add files to the change
 #
-activity="make transparent 390"
+activity="make transparent 393"
 $bin/aegis -mt $workchan/bogus -nl > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="check file contents 394"
+activity="check file contents 397"
 cat > ok << 'end'
 the trunk version
 end
@@ -403,7 +403,7 @@ if test $? -ne 0 ; then no_result; fi
 diff ok $workchan/bogus
 if test $? -ne 0 ; then fail; fi
 
-activity="check change file state 403"
+activity="check change file state 406"
 cat > ok << 'end'
 src =
 [
@@ -435,7 +435,7 @@ if test $? -ne 0 ; then no_result; fi
 #
 # build
 #
-activity="build 426"
+activity="build 438"
 $bin/aegis -build -nl > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
@@ -443,7 +443,7 @@ if test $? -ne 0 ; then cat log; fail; fi
 # now chek the bogus file again
 # the symlink should point to the right place.
 #
-activity="check symlinks 390"
+activity="check symlinks 446"
 cat > ok << 'end'
 the trunk version
 end
@@ -452,7 +452,7 @@ if test $? -ne 0 ; then no_result; fi
 diff ok $workchan/bogus
 if test $? -ne 0 ; then fail; fi
 
-activity="check change state 430"
+activity="check change state 455"
 cat > ok << 'end'
 brief_description = "The third change";
 description = "The third change";
@@ -499,11 +499,11 @@ check_it ok $workproj/info/change/0/002.branch/0/004
 #
 # diff
 #
-activity="diff 475"
+activity="diff 502"
 $bin/aegis -diff -nl > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="check change state 479"
+activity="check change state 506"
 cat > ok << 'end'
 brief_description = "The third change";
 description = "The third change";
@@ -547,7 +547,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.branch/0/004
 
-activity="check change file state 521"
+activity="check change file state 550"
 cat > ok << 'end'
 src =
 [
@@ -583,11 +583,11 @@ check_it ok $workproj/info/change/0/002.branch/0/004.fs
 #
 # develop end
 #
-activity="develop end 556"
+activity="develop end 586"
 $bin/aegis -de > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="check change file state 560"
+activity="check change file state 590"
 cat > ok << 'end'
 src =
 [
@@ -620,7 +620,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.branch/0/004.fs
 
-activity="check change state 592"
+activity="check change state 623"
 cat > ok << 'end'
 brief_description = "The third change";
 description = "The third change";
@@ -669,7 +669,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.branch/0/004
 
-activity="check branch file state 639"
+activity="check branch file state 672"
 cat > ok << 'end'
 src =
 [
@@ -711,39 +711,39 @@ check_it ok $workproj/info/change/0/002.fs
 #
 # review pass
 #
-activity="review pass 680"
+activity="review pass 714"
 $bin/aegis --review-pass 4 > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # integrate begin
 #
-activity="integrate begin 687"
+activity="integrate begin 721"
 $bin/aegis --integrate-begin 4 > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # build
 #
-activity="build 694"
+activity="build 728"
 $bin/aegis -build -nl > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # diff
 #
-activity="diff 701"
+activity="diff 735"
 $bin/aegis -diff -nl > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # pass the integration
 #
-activity="integrate pass 708"
+activity="integrate pass 742"
 $bin/aegis -intpass -nl > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="check change file state 712"
+activity="check change file state 746"
 cat > ok << 'end'
 src =
 [
@@ -764,7 +764,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.branch/0/004.fs
 
-activity="check change state 732"
+activity="check change state 767"
 cat > ok << 'end'
 brief_description = "The third change";
 description = "The third change";
@@ -826,7 +826,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.branch/0/004
 
-activity="check branch file state 790"
+activity="check branch file state 829"
 cat > ok << 'end'
 src =
 [
@@ -862,11 +862,11 @@ export AEGIS_PROJECT
 #
 # develop end
 #
-activity="develop end 825"
+activity="develop end 865"
 $bin/aegis -de 2 > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
-activity="check change file state 829"
+activity="check change file state 869"
 cat > ok << 'end'
 src =
 [
@@ -892,7 +892,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.fs
 
-activity="check change state 854"
+activity="check change state 895"
 cat > ok << 'end'
 brief_description = "A bogus project created to test the aemt functionality, branch 2.";
 description = "A bogus project created to test the aemt functionality, branch 2.";
@@ -945,6 +945,7 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = true;
+	default_test_regression_exemption = true;
 	skip_unlucky = false;
 	compress_database = false;
 	develop_end_action = goto_being_reviewed;
@@ -992,10 +993,32 @@ check_it ok $workproj/info/change/0/002
 
 # The transparent file should NOT be locked
 # when its coming from a branch that it was transparent in.
-activity="check trunk file state 954"
+activity="check trunk file state 995"
 cat > ok << 'end'
 src =
 [
+	{
+		file_name = "aegis.conf";
+		uuid = "UUID";
+		action = create;
+		edit =
+		{
+			revision = "1.1";
+			encoding = none;
+		};
+		edit_origin =
+		{
+			revision = "1.1";
+			encoding = none;
+		};
+		usage = config;
+		file_fp =
+		{
+			youngest = TIME;
+			oldest = TIME;
+			crypto = "GUNK";
+		};
+	},
 	{
 		file_name = "bogus";
 		uuid = "UUID";
@@ -1018,28 +1041,6 @@ src =
 			crypto = "GUNK";
 		};
 	},
-	{
-		file_name = "config";
-		uuid = "UUID";
-		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		usage = config;
-		file_fp =
-		{
-			youngest = TIME;
-			oldest = TIME;
-			crypto = "GUNK";
-		};
-	},
 ];
 end
 if test $? -ne 0 ; then no_result; fi
@@ -1049,32 +1050,32 @@ check_it ok $workproj/info/trunk.fs
 #
 # review pass
 #
-activity="review pass 1009"
+activity="review pass 1052"
 $bin/aegis --review-pass 2 > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # integrate begin
 #
-activity="integrate begin 1016"
+activity="integrate begin 1059"
 $bin/aegis --integrate-begin 2 > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # build
 #
-activity="build 1023"
+activity="build 1066"
 $bin/aegis -build -nl > log 2>&1
 if test $? -ne 0 ; then cat log; fail; fi
 
 #
 # pass the integration
 #
-activity="integrate pass 1030"
+activity="integrate pass 1073"
 $bin/aegis -intpass -nl 2 > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
-activity="check change file state 1034"
+activity="check change file state 1077"
 cat > ok << 'end'
 src =
 [
@@ -1100,7 +1101,7 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002.fs
 
-activity="check change state 1059"
+activity="check change state 1103"
 cat > ok << 'end'
 brief_description = "A bogus project created to test the aemt functionality, branch 2.";
 description = "A bogus project created to test the aemt functionality, branch 2.";
@@ -1162,6 +1163,7 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = true;
+	default_test_regression_exemption = true;
 	skip_unlucky = false;
 	compress_database = false;
 	develop_end_action = goto_being_reviewed;
@@ -1207,28 +1209,12 @@ if test $? -ne 0 ; then no_result; fi
 
 check_it ok $workproj/info/change/0/002
 
-activity="check trunk file state 1164"
+activity="check trunk file state 1210"
 cat > ok << 'end'
 src =
 [
 	{
-		file_name = "bogus";
-		uuid = "UUID";
-		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		usage = source;
-	},
-	{
-		file_name = "config";
+		file_name = "aegis.conf";
 		uuid = "UUID";
 		action = create;
 		edit =
@@ -1249,6 +1235,22 @@ src =
 			crypto = "GUNK";
 		};
 	},
+	{
+		file_name = "bogus";
+		uuid = "UUID";
+		action = create;
+		edit =
+		{
+			revision = "1.1";
+			encoding = none;
+		};
+		edit_origin =
+		{
+			revision = "1.1";
+			encoding = none;
+		};
+		usage = source;
+	},
 ];
 end
 if test $? -ne 0 ; then no_result; fi
